## Info

- program: licensecheck
- version: dev
- license: MIT LICENSE

## Project License

MIT LICENSE

## Packages

Find a list of packages below

|Compatible|Package|
|:--|:--|
|✖|example|

### example-UNKNOWN

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: UNKNOWN
- Compatible: False
- Size: -1
